@@ -4,12 +4,13 @@ from typing import Dict, List, Optional
 
 import uvicorn
 from fastapi import FastAPI
+
 from lof.code_gen import create_temp_app_folder, generate_app
 from lof.env_vars import path_for_env_file, set_env_variables
 from lof.errors import NoTemplate, NoVariablesFile
 from lof.generator import create_middleware, create_route
 from lof.parser import get_endpoints
-from lof.aws_context import Context
+from lof.providers.aws import Context
 
 
 def validate_paths(template_file: str, variables_file: str) -> None:
@@ -42,7 +43,7 @@ def run_fast_api_server(lambdas: List[Dict], proxy_lambdas: List[Dict]) -> FastA
             method=_lambda["method"],
             handler=_lambda["handler"],
             app=app,
-            lambda_name=_lambda["name"]
+            lambda_name=_lambda["name"],
         )
     return app
 
